@@ -6,10 +6,9 @@ import pytest
 @pytest.fixture(scope="module")
 def install():
     pytest.helpers.clean_env()
-    pytest.helpers.run_command(
-        [pytest.INST_BIN, "/master=cli_master", "/minion-name=cli_minion"]
-    )
-    yield
+    args = ["/master=cli_master", "/minion-name=cli_minion"]
+    pytest.helpers.install_salt(args)
+    yield args
     pytest.helpers.clean_env()
 
 
