@@ -6,15 +6,13 @@ import pytest
 @pytest.fixture(scope="module")
 def install():
     pytest.helpers.clean_env()
-
     # Create an existing config
     pytest.helpers.existing_config()
-
     # Create a custom config
     pytest.helpers.custom_config()
-
-    pytest.helpers.run_command([pytest.INST_BIN, "/custom-config=custom_conf"])
-    yield
+    args = ["/custom-config=custom_conf"]
+    pytest.helpers.install_salt(args)
+    yield args
     pytest.helpers.clean_env()
 
 
@@ -28,7 +26,7 @@ def test_config_present(install):
 
 def test_config_correct(install):
     # The config file should be the default, unchanged
-    with open(f"{pytest.REPO_DIR}\\custom_conf") as f:
+    with open(f"{pytest.SCRIPT_DIR}\\custom_conf") as f:
         expected = f.readlines()
 
     with open(f"{pytest.DATA_DIR}\\conf\\minion") as f:
