@@ -2,7 +2,6 @@
 Integration tests for the Dimension Data cloud provider
 """
 
-
 from tests.integration.cloud.helpers.cloud_test_base import TIMEOUT, CloudTest
 
 
@@ -18,14 +17,14 @@ class DimensionDataTest(CloudTest):
         """
         Tests the return of running the --list-images command for the dimensiondata cloud provider
         """
-        image_list = self.run_cloud("--list-images {}".format(self.PROVIDER))
+        image_list = self.run_cloud(f"--list-images {self.PROVIDER}")
         self.assertIn("Ubuntu 14.04 2 CPU", [i.strip() for i in image_list])
 
     def test_list_locations(self):
         """
         Tests the return of running the --list-locations command for the dimensiondata cloud provider
         """
-        _list_locations = self.run_cloud("--list-locations {}".format(self.PROVIDER))
+        _list_locations = self.run_cloud(f"--list-locations {self.PROVIDER}")
         self.assertIn(
             "Australia - Melbourne MCP2", [i.strip() for i in _list_locations]
         )
@@ -34,7 +33,7 @@ class DimensionDataTest(CloudTest):
         """
         Tests the return of running the --list-sizes command for the dimensiondata cloud provider
         """
-        _list_sizes = self.run_cloud("--list-sizes {}".format(self.PROVIDER))
+        _list_sizes = self.run_cloud(f"--list-sizes {self.PROVIDER}")
         self.assertIn("default", [i.strip() for i in _list_sizes])
 
     def test_instance(self):
@@ -43,7 +42,7 @@ class DimensionDataTest(CloudTest):
         """
         # check if instance with salt installed returned
         ret_val = self.run_cloud(
-            "-p dimensiondata-test {}".format(self.instance_name), timeout=TIMEOUT
+            f"-p dimensiondata-test {self.instance_name}", timeout=TIMEOUT
         )
         self.assertInstanceExists(ret_val)
 
