@@ -1,6 +1,9 @@
 import pytest
 
 import salt.modules.cmdmod as cmdmod
+from salt.exceptions import CommandExecutionError
+
+pytestmark = [pytest.mark.windows_whitelisted]
 
 
 @pytest.fixture(scope="module")
@@ -20,7 +23,12 @@ def configure_loader_modules():
 
 @pytest.mark.skip_on_windows
 @pytest.mark.skip_if_not_root
-def test_run_as(account):
+def test_runas(account):
     ret = cmdmod.run("id", runas=account.username)
     assert f"gid={account.info.gid}" in ret
     assert f"uid={account.info.uid}" in ret
+
+
+def test_runas_missing_user():
+    with pytest.raises(CommandExecutionError):
+        cmdmod.run("echo HOLO", runas="non-existent-user", password="junk")
