@@ -39,7 +39,18 @@ def holy(state_tree_prod):
 
 @pytest.fixture
 def grail_scene33_file(grail):
-    return grail / "scene33"
+    signed_file = grail / "scene33"
+    hash_file = signed_file.with_suffix(".SHA256")
+    for test_file in (signed_file, hash_file):
+        content = test_file.read_bytes()
+        content = content.replace(b"\r\n", b"\n")
+        test_file.write_bytes(content)
+    return signed_file
+
+
+@pytest.fixture
+def grail_scene33_clearsign_file(grail_scene33_file):
+    return grail_scene33_file.with_suffix(".clearsign.asc")
 
 
 @pytest.fixture
@@ -47,6 +58,11 @@ def grail_scene33_file_hash(grail_scene33_file):
     return hashlib.sha256(grail_scene33_file.read_bytes()).hexdigest()
 
 
+@pytest.fixture
+def grail_scene33_clearsign_file_hash(grail_scene33_clearsign_file):
+    return hashlib.sha256(grail_scene33_clearsign_file.read_bytes()).hexdigest()
+
+
 @pytest.fixture(scope="module")
 def state_file_account():
     with pytest.helpers.create_account(create_group=True) as system_account:
