@@ -38,17 +38,19 @@ def state_tree_dir(base_env_state_tree_root_dir):
     State tree with files to test salt-ssh
     when the map.jinja file is in another directory
     """
+    # Remove unused import from top file to avoid salt-ssh file sync issues
+    # Use "testdir" instead of "test" to avoid conflicts with state_tree fixture
     top_file = """
-    {%- from "test/map.jinja" import abc with context %}
     base:
       'localhost':
-        - test
+        - testdir
       '127.0.0.1':
-        - test
+        - testdir
     """
     map_file = """
     {%- set abc = "def" %}
     """
+    # State file imports from subdirectory - this is what we're testing
     state_file = """
     {%- from "test/map.jinja" import abc with context %}
 
@@ -61,8 +63,9 @@ def state_tree_dir(base_env_state_tree_root_dir):
     map_tempfile = pytest.helpers.temp_file(
         "test/map.jinja", map_file, base_env_state_tree_root_dir
     )
+    # Use testdir.sls to avoid collision with state_tree's test.sls
     state_tempfile = pytest.helpers.temp_file(
-        "test.sls", state_file, base_env_state_tree_root_dir
+        "testdir.sls", state_file, base_env_state_tree_root_dir
     )
 
     with top_tempfile, map_tempfile, state_tempfile:
@@ -78,17 +81,18 @@ def nested_state_tree(base_env_state_tree_root_dir, tmp_path):
       '127.0.0.1':
         - basic
     """
+    # Inline the Jinja template content to avoid salt-ssh file server lookup issues
+    # The template imports from foo/map.jinja which still needs to exist as a file
+    file_jinja_content = """{% from 'foo/map.jinja' import comment %}{{ comment }}"""
     state_file = """
     /{}/file.txt:
       file.managed:
-        - source: salt://foo/file.jinja
+        - contents: |
+            {}
         - template: jinja
     """.format(
-        tmp_path
+        tmp_path, file_jinja_content
     )
-    file_jinja = """
-    {% from 'foo/map.jinja' import comment %}{{ comment }}
-    """
     map_file = """
     {% set comment = "blah blah" %}
     """
@@ -97,10 +101,9 @@ def nested_state_tree(base_env_state_tree_root_dir, tmp_path):
         "top.sls", top_file, base_env_state_tree_root_dir
     )
     map_tempfile = pytest.helpers.temp_file("map.jinja", map_file, statedir)
-    file_tempfile = pytest.helpers.temp_file("file.jinja", file_jinja, statedir)
     state_tempfile = pytest.helpers.temp_file("init.sls", state_file, statedir)
 
-    with top_tempfile, map_tempfile, state_tempfile, file_tempfile:
+    with top_tempfile, map_tempfile, state_tempfile:
         yield
 
 
