@@ -14,6 +14,16 @@ import salt.utils.platform
 from tests.support.mock import MagicMock, patch
 from tests.support.runtests import RUNTIME_VARS
 
+try:
+    import pygit2  # pylint: disable=unused-import
+
+    HAS_PYGIT2 = True
+except ImportError:
+    HAS_PYGIT2 = False
+
+
+skipif_no_pygit2 = pytest.mark.skipif(not HAS_PYGIT2, reason="Missing pygit2")
+
 
 @pytest.fixture
 def maintenance_opts(master_opts):
@@ -1166,6 +1176,7 @@ def allowed_funcs(tmp_path):
     return salt.master.AESFuncs(opts=opts)
 
 
+@skipif_no_pygit2
 def test_on_demand_allowed_command_injection(allowed_funcs, tmp_path, caplog):
     """
     Verify on demand pillars validate remote urls
