@@ -9,12 +9,31 @@ import time
 from contextlib import contextmanager
 
 import salt.utils.event
-from salt.utils.process import clean_proc
+from salt.utils.process import Process, clean_proc
 
 
 @contextmanager
 def eventpublisher_process(sock_dir):
-    proc = salt.utils.event.EventPublisher({"sock_dir": sock_dir})
+    opts = {
+        "sock_dir": sock_dir,
+        "interface": "127.0.0.1",
+        "publish_port": 4506,
+        "ipv6": None,
+        "zmq_filtering": None,
+    }
+    ipc_publisher = salt.transport.publish_server(
+        opts,
+        pub_path=os.path.join(opts["sock_dir"], "master_event_pub.ipc"),
+        pull_path=os.path.join(opts["sock_dir"], "master_event_pull.ipc"),
+        transport="tcp",
+    )
+    proc = Process(
+        target=ipc_publisher.publish_daemon,
+        args=[
+            ipc_publisher.publish_payload,
+        ],
+    )
+    # proc = salt.utils.event.EventPublisher({"sock_dir": sock_dir})
     proc.start()
     try:
         if os.environ.get("TRAVIS_PYTHON_VERSION", None) is not None:
