@@ -559,6 +559,11 @@ class LazyLoaderReloadingTest(TestCase):
             os.makedirs(RUNTIME_VARS.TMP)
 
     def setUp(self):
+        # Prevent .pyc files from being written to avoid performance issues
+        # when modules are reloaded quickly (see TODO comments below)
+        self._original_dont_write_bytecode = sys.dont_write_bytecode
+        sys.dont_write_bytecode = True
+
         self.tmp_dir = tempfile.mkdtemp(dir=RUNTIME_VARS.TMP)
         self.addCleanup(shutil.rmtree, self.tmp_dir, ignore_errors=True)
 
@@ -581,6 +586,9 @@ class LazyLoaderReloadingTest(TestCase):
         )
 
     def tearDown(self):
+        # Restore original dont_write_bytecode setting
+        sys.dont_write_bytecode = self._original_dont_write_bytecode
+
         for attrname in ("tmp_dir", "utils", "proxy", "loader", "minion_mods", "utils"):
             try:
                 delattr(self, attrname)
@@ -602,15 +610,11 @@ class LazyLoaderReloadingTest(TestCase):
             fh.flush()
             os.fsync(fh.fileno())  # flush to disk
 
-        # pyc files don't like it when we change the original quickly
-        # since the header bytes only contain the timestamp (granularity of seconds)
-        # TODO: don't write them? Is *much* slower on re-load (~3x)
-        # https://docs.python.org/2/library/sys.html#sys.dont_write_bytecode
-        remove_bytecode(self.module_path)
+        # .pyc files are prevented by sys.dont_write_bytecode = True in setUp()
 
     def rm_module(self):
         os.unlink(self.module_path)
-        remove_bytecode(self.module_path)
+        # .pyc files are prevented by sys.dont_write_bytecode = True in setUp()
 
     @property
     def module_path(self):
