@@ -4,8 +4,8 @@ Unit Tests for functions located in salt.utils.state.py.
 
 import copy
 import textwrap
+from collections import OrderedDict
 
-import salt.utils.odict
 import salt.utils.state
 from tests.support.unit import TestCase
 
@@ -33,11 +33,11 @@ class StateUtilTestCase(TestCase):
         test_valid_state = {"host1": {"test_state": {"result": "We have liftoff!"}}}
         self.assertTrue(salt.utils.state.check_result(test_valid_state))
         test_valid_false_states = {
-            "test1": salt.utils.odict.OrderedDict(
+            "test1": OrderedDict(
                 [
                     (
                         "host1",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": False}),
@@ -46,11 +46,11 @@ class StateUtilTestCase(TestCase):
                     ),
                 ]
             ),
-            "test2": salt.utils.odict.OrderedDict(
+            "test2": OrderedDict(
                 [
                     (
                         "host1",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": True}),
@@ -59,7 +59,7 @@ class StateUtilTestCase(TestCase):
                     ),
                     (
                         "host2",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": False}),
@@ -69,15 +69,15 @@ class StateUtilTestCase(TestCase):
                 ]
             ),
             "test3": ["a"],
-            "test4": salt.utils.odict.OrderedDict(
+            "test4": OrderedDict(
                 [
                     (
                         "asup",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 (
                                     "host1",
-                                    salt.utils.odict.OrderedDict(
+                                    OrderedDict(
                                         [
                                             ("test_state0", {"result": True}),
                                             ("test_state", {"result": True}),
@@ -86,7 +86,7 @@ class StateUtilTestCase(TestCase):
                                 ),
                                 (
                                     "host2",
-                                    salt.utils.odict.OrderedDict(
+                                    OrderedDict(
                                         [
                                             ("test_state0", {"result": True}),
                                             ("test_state", {"result": False}),
@@ -98,22 +98,22 @@ class StateUtilTestCase(TestCase):
                     )
                 ]
             ),
-            "test5": salt.utils.odict.OrderedDict(
+            "test5": OrderedDict(
                 [
                     (
                         "asup",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 (
                                     "host1",
-                                    salt.utils.odict.OrderedDict(
+                                    OrderedDict(
                                         [
                                             ("test_state0", {"result": True}),
                                             ("test_state", {"result": True}),
                                         ]
                                     ),
                                 ),
-                                ("host2", salt.utils.odict.OrderedDict([])),
+                                ("host2", OrderedDict([])),
                             ]
                         ),
                     )
@@ -123,11 +123,11 @@ class StateUtilTestCase(TestCase):
         for test, data in test_valid_false_states.items():
             self.assertFalse(salt.utils.state.check_result(data), msg=f"{test} failed")
         test_valid_true_states = {
-            "test1": salt.utils.odict.OrderedDict(
+            "test1": OrderedDict(
                 [
                     (
                         "host1",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": True}),
@@ -136,11 +136,11 @@ class StateUtilTestCase(TestCase):
                     ),
                 ]
             ),
-            "test3": salt.utils.odict.OrderedDict(
+            "test3": OrderedDict(
                 [
                     (
                         "host1",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": True}),
@@ -149,7 +149,7 @@ class StateUtilTestCase(TestCase):
                     ),
                     (
                         "host2",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": True}),
@@ -158,15 +158,15 @@ class StateUtilTestCase(TestCase):
                     ),
                 ]
             ),
-            "test4": salt.utils.odict.OrderedDict(
+            "test4": OrderedDict(
                 [
                     (
                         "asup",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 (
                                     "host1",
-                                    salt.utils.odict.OrderedDict(
+                                    OrderedDict(
                                         [
                                             ("test_state0", {"result": True}),
                                             ("test_state", {"result": True}),
@@ -175,7 +175,7 @@ class StateUtilTestCase(TestCase):
                                 ),
                                 (
                                     "host2",
-                                    salt.utils.odict.OrderedDict(
+                                    OrderedDict(
                                         [
                                             ("test_state0", {"result": True}),
                                             ("test_state", {"result": True}),
@@ -187,11 +187,11 @@ class StateUtilTestCase(TestCase):
                     )
                 ]
             ),
-            "test2": salt.utils.odict.OrderedDict(
+            "test2": OrderedDict(
                 [
                     (
                         "host1",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": None}),
                                 ("test_state", {"result": True}),
@@ -200,7 +200,7 @@ class StateUtilTestCase(TestCase):
                     ),
                     (
                         "host2",
-                        salt.utils.odict.OrderedDict(
+                        OrderedDict(
                             [
                                 ("test_state0", {"result": True}),
                                 ("test_state", {"result": "abc"}),
@@ -214,11 +214,11 @@ class StateUtilTestCase(TestCase):
             self.assertTrue(salt.utils.state.check_result(data), msg=f"{test} failed")
         test_invalid_true_ht_states = {
             "test_onfail_simple2": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     ("test_vstate0", {"result": False}),
                                     ("test_vstate1", {"result": True}),
@@ -232,7 +232,7 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -241,17 +241,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", True),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_vstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_vstate0")])],
                                     ),
                                 ]
                             ),
@@ -262,11 +258,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),
             "test_onfail_integ2": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     (
                                         "t_|-test_ivstate0_|-echo_|-run",
@@ -290,12 +286,12 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
                         "t": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -304,17 +300,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", False),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_ivstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_ivstate0")])],
                                     ),
                                 ]
                             ),
@@ -325,11 +317,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),
             "test_onfail_integ3": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     (
                                         "t_|-test_ivstate0_|-echo_|-run",
@@ -353,12 +345,12 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
                         "t": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -367,17 +359,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", False),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_ivstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_ivstate0")])],
                                     ),
                                 ]
                             ),
@@ -388,11 +376,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),
             "test_onfail_integ4": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     (
                                         "t_|-test_ivstate0_|-echo_|-run",
@@ -416,12 +404,12 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
                         "t": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -430,17 +418,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", False),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_ivstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_ivstate0")])],
                                     ),
                                 ]
                             ),
@@ -452,17 +436,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", True),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_ivstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_ivstate0")])],
                                     ),
                                 ]
                             ),
@@ -473,11 +453,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),
             "test_onfail": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     ("test_state0", {"result": False}),
                                     ("test_state", {"result": True}),
@@ -489,11 +469,11 @@ class StateUtilTestCase(TestCase):
                 None,
             ),
             "test_onfail_d": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     ("test_state0", {"result": False}),
                                     ("test_state", {"result": True}),
@@ -519,11 +499,11 @@ class StateUtilTestCase(TestCase):
 
         test_valid_true_ht_states = {
             "test_onfail_integ": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     (
                                         "cmd_|-test_ivstate0_|-echo_|-run",
@@ -543,7 +523,7 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -552,17 +532,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", False),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_ivstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_ivstate0")])],
                                     ),
                                 ]
                             ),
@@ -573,11 +549,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),
             "test_onfail_intega3": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     (
                                         "t_|-test_ivstate0_|-echo_|-run",
@@ -601,12 +577,12 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
                         "t": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -615,17 +591,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", False),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_ivstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_ivstate0")])],
                                     ),
                                 ]
                             ),
@@ -636,11 +608,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),
             "test_onfail_simple": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     ("test_vstate0", {"result": False}),
                                     ("test_vstate1", {"result": True}),
@@ -654,7 +626,7 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -663,17 +635,13 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     ("onfail_stop", False),
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_vstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_vstate0")])],
                                     ),
                                 ]
                             ),
@@ -684,11 +652,11 @@ class StateUtilTestCase(TestCase):
                 },
             ),  # order is different
             "test_onfail_simple_rev": (
-                salt.utils.odict.OrderedDict(
+                OrderedDict(
                     [
                         (
                             "host1",
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict(
                                 [
                                     ("test_vstate0", {"result": False}),
                                     ("test_vstate1", {"result": True}),
@@ -702,7 +670,7 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
+                            OrderedDict([("name", "/bin/true")]),
                             "run",
                             {"order": 10002},
                         ],
@@ -711,20 +679,16 @@ class StateUtilTestCase(TestCase):
                         "__env__": "base",
                         "__sls__": "a",
                         "cmd": [
-                            salt.utils.odict.OrderedDict([("name", "/bin/true")]),
-                            salt.utils.odict.OrderedDict(
+                            OrderedDict([("name", "/bin/true")]),
+                            OrderedDict(
                                 [
                                     (
                                         "onfail",
-                                        [
-                                            salt.utils.odict.OrderedDict(
-                                                [("cmd", "test_vstate0")]
-                                            )
-                                        ],
+                                        [OrderedDict([("cmd", "test_vstate0")])],
                                     )
                                 ]
                             ),
-                            salt.utils.odict.OrderedDict([("onfail_stop", False)]),
+                            OrderedDict([("onfail_stop", False)]),
                             "run",
                             {"order": 10004},
                         ],
